@@ -76,7 +76,7 @@
 #define ID_WIZARD 2905
 #define ID_TAB 2904
 
-TQString pageTitle[] = {
+TQCString pageTitle[] = {
     I18N_NOOP( "F&iles" ),
     I18N_NOOP( "Des&tination" ),
     I18N_NOOP( "P&lugins" ),
@@ -1004,7 +1004,7 @@ void KRenameImpl::start()
     }
 
     ProgressDialog* p = new ProgressDialog( 0, "p" );
-    p->print(TQString( i18n("Starting conversion of %1 files.") ).arg(fileList->count()));
+    p->print(i18n("Starting conversion of %1 files.").arg(fileList->count()));
 
     // Save History
     dirname->saveSettings();
@@ -1065,7 +1065,7 @@ bool KRenameImpl::checkErrors()
 
 void KRenameImpl::updateCount()
 {
-    labelCount->setText( TQString( i18n("Files: <b>%1</b>") ).arg(fileList->count()));
+    labelCount->setText(i18n("Files: <b>%1</b>").arg(fileList->count()));
 
     buttonCoord->setEnabled( (bool)fileList->count() );
     buttonReplace->setEnabled( (bool)fileList->count() );
@@ -1161,27 +1161,31 @@ bool KRenameImpl::setupBatchRenamer( BatchRenamer* b, bool preview )
         TQString url = urlrequester->url();
         if( url.right(1) != "/" )
             url.append( "/" );
-        
-        if( !TDEIO::NetAccess::exists( KURL( url ) ) )
+
+        if (!TDEIO::NetAccess::exists(KURL(url), true, parent))
         {
             int m = KMessageBox::warningContinueCancel( parent, i18n("The directory %1 does not exist. "
             "KRename will create it for you.").arg( url ) );
             if( m == KMessageBox::Cancel )
                 return false;
-            
+
             int i = 0;
             TQString d = "/";
-            while( (d += url.section( "/", i, i, TQString::SectionSkipEmpty )) && ! d.isEmpty() ) { // asignment here!
-                if( !TDEIO::NetAccess::exists( d ) && !TDEIO::NetAccess::mkdir( d ) )
+            TQString ds = TQString::null;
+            for (ds = url.section("/", i, i, TQString::SectionSkipEmpty);
+                 !ds.isEmpty();
+                 i++, d.append("/"), ds = url.section("/", i, i, TQString::SectionSkipEmpty))
+            {
+                d += ds;
+                if (!TDEIO::NetAccess::exists(d, false, parent) &&
+                    !TDEIO::NetAccess::mkdir(d, parent, -1))
                 {
                     tqDebug( "Can't create %s", d.latin1() );
                     break;
                 }
-                d.append( "/" );
-                i++;
             }
         }
-            
+
         b->setDirname( url );
         b->setOverwrite( checkOverwrite->isChecked() );
         b->setUndo( checkUndoScript->isChecked() && !optionCopy->isChecked() );
@@ -1834,3 +1838,5 @@ void KRenameImpl::slotEasy4()
 {
     getHelpDialogString( comboCustomExtension->lineEdit() );
 }
+
+#include "krenameimpl.moc"
